from django.conf.urls import url
from django.contrib.auth import views as django_auth_views

from wagtail.wagtailadmin.views import account as wagtail_account_views

from axes.decorators import watch_login

from wagtailenforcer.views import account as account_views
from wagtailenforcer.views.wagtailusers import users

# Here we put all the overriden Wagtail urls from the different wagtail apps

urlpatterns = [
    url(r'^password_reset/$', account_views.password_reset, name='wagtailadmin_password_reset'),
    url(r'^password_reset/done/$', account_views.password_reset_done, name='wagtailadmin_password_reset_done'),
    url(
        r'^password_reset/confirm/(?P<uidb64>[0-9A-Za-z_\-]+)/(?P<token>[0-9A-Za-z]{1,13}-[0-9A-Za-z]{1,20})/$',
        account_views.password_reset_confirm,
        name='wagtailadmin_password_reset_confirm',
    ),
    url(r'^password_reset/complete/$', account_views.password_reset_complete, name='wagtailadmin_password_reset_complete'),

    url(r'^login/$', watch_login(wagtail_account_views.login), name='wagtailadmin_login'),

    url(r'^users/(\d+)/$', users.edit, name='wagtailusers_users_edit'),
    url(r'^users/new/$', users.create, name='wagtailusers_users_create'),

]



from wagtail.wagtailadmin.views import account as account_views


def password_reset(request, **kwargs):
    from wagtailenforcer.forms.wagtailusers import PasswordResetForm
    kwargs.update({
        'template_name': 'wagtailadmin/account/password_reset/form.html',
        'email_template_name': 'wagtailadmin/account/password_reset/email.txt',
        'subject_template_name': 'wagtailadmin/account/password_reset/email_subject.txt',
        'password_reset_form': PasswordResetForm,
        'post_reset_redirect': 'wagtailadmin_password_reset_done',
    })
    return account_views.password_reset(request, **kwargs)


def password_reset_done(request, **kwargs):
    kwargs.update({
        'template_name': 'wagtailadmin/account/password_reset/done.html'
    })
    return account_views.password_reset_done(request, **kwargs)


def password_reset_confirm(request, **kwargs):
    from wagtailenforcer.forms.wagtailusers import PasswordForm
    kwargs.update({
        'template_name': 'wagtailadmin/account/password_reset/enforce_confirm.html',
        'post_reset_redirect': 'wagtailadmin_password_reset_complete',
        'set_password_form': PasswordForm,
        'extra_context': {'reset_password_url': '/admin/password_reset'},
    })
    return account_views.password_reset_confirm(request, **kwargs)


def password_reset_complete(request, **kwargs):
    kwargs.update({
        'template_name': 'wagtailadmin/account/password_reset/complete.html'
    })
    return account_views.password_reset_complete(request, **kwargs)



from django.conf.urls import url

from wagtailenforcer.views.axes import views as axes_views

# Here we put all the new Wagtail admin urls

urlpatterns = [
    url(r'^$', axes_views.list, name='wagtailenforcer_blocked_users'),
    url(r'^reset/(\d+)/$', axes_views.reset, name='wagtailenforcer_unblock_user'),
]
